use x_log::*;

fn main() {
    XLog::new().init().unwrap();

    let xx = file!();
    log::trace!("This is an example message. {}", xx);
    log::debug!("This is an example message.");
    info!("This is an example message.");
    warn!("This is an example message.");
    log::error!("This is an example message.");

}